==> gitlab_16.11.6.orig.tar.bz2: gitlab-foss-v16.11.6/spec/frontend/super_sidebar/components/global_search/components/command_overview_dropdown_spec.js <==
import { GlDisclosureDropdown, GlSprintf, GlDisclosureDropdownItem } from '@gitlab/ui';
import { shallowMountExtended } from 'helpers/vue_test_utils_helper';
import CommandsOverviewDropdown from '~/super_sidebar/components/global_search/command_palette/command_overview_dropdown.vue';

describe('CommandsOverviewDropdown', () => {
  let wrapper;

  const createComponent = () => {
    wrapper = shallowMountExtended(CommandsOverviewDropdown, {
      propsData: {
        items: [
          {
            value: '>',
            text: 'Pages',
          },
          {
            value: '@',
            text: 'Users',
          },
          {
            value: ':',
            text: 'Projects',
          },
          {
            value: '~',
            text: 'Pages',
          },
        ],
      },
      stubs: {
        GlDisclosureDropdown,
        GlDisclosureDropdownItem,
        GlSprintf,
      },
    });
  };

  const findDropdow = () => wrapper.findComponent(GlDisclosureDropdown);
  const findItems = () => wrapper.findAllComponents(GlDisclosureDropdownItem);
  const findItemTitles = () =>
    findItems().wrappers.map((w) => w.find('[data-testid="disclosure-dropdown-item"]').text());

  beforeEach(() => {
    createComponent();
  });

  describe('template', () => {
    it('renders header', () => {
      expect(findDropdow().find('span').text()).toBe('I’m looking for');
    });

    it('renders all items', () => {
      expect(findItems()).toHaveLength(4);
    });

    it('renders item correctly', () => {
      expect(findItemTitles()).toHaveLength(4);
    });
  });

  describe('events', () => {
    it('renders header', () => {
      findDropdow().vm.$emit('action', { value: '@' });
      expect(wrapper.emitted('selected')).toEqual([['@']]);
    });
  });
});

==> gitlab_17.0.8.orig.tar.bz2: gitlab-foss-v17.0.8/spec/frontend/super_sidebar/components/global_search/components/command_overview_dropdown_spec.js <==
import { GlListboxItem, GlSprintf, GlCollapsibleListbox } from '@gitlab/ui';
import { shallowMountExtended } from 'helpers/vue_test_utils_helper';
import CommandsOverviewDropdown from '~/super_sidebar/components/global_search/command_palette/command_overview_dropdown.vue';

describe('CommandsOverviewDropdown', () => {
  let wrapper;

  const createComponent = () => {
    wrapper = shallowMountExtended(CommandsOverviewDropdown, {
      propsData: {
        items: [
          {
            value: '>',
            text: 'Pages',
          },
          {
            value: '@',
            text: 'Users',
          },
          {
            value: ':',
            text: 'Projects',
          },
          {
            value: '~',
            text: 'Pages',
          },
        ],
      },
      stubs: {
        GlCollapsibleListbox,
        GlListboxItem,
        GlSprintf,
      },
    });
  };

  const findDropdown = () => wrapper.findComponent(GlCollapsibleListbox);
  const findItems = () => wrapper.findAllComponents(GlListboxItem);
  const findItemTitles = () =>
    findItems().wrappers.map((w) => w.find('[data-testid="listbox-item-text"]').text());

  beforeEach(() => {
    createComponent();
  });

  describe('template', () => {
    it('renders header', () => {
      expect(findDropdown().find('[data-testid="listbox-header-text"]').text()).toBe(
        'I’m looking for',
      );
    });

    it('renders all items', () => {
      expect(findItems()).toHaveLength(4);
    });

    it('renders item correctly', () => {
      expect(findItemTitles()).toHaveLength(4);
    });
  });

  describe('events', () => {
    it('renders header', () => {
      findDropdown().vm.$emit('select', '@');
      expect(wrapper.emitted('selected')).toEqual([['@']]);
    });
  });
});
